==> org.eclipse.incquery.uml.source_1.0.0.201504211455.jar: org/eclipse/incquery/uml/derivedfeatures/NamedElementQualifiedNameMatch.java <==
package org.eclipse.incquery.uml.derivedfeatures;

import java.util.Arrays;
import java.util.List;
import org.eclipse.incquery.runtime.api.IPatternMatch;
import org.eclipse.incquery.runtime.api.impl.BasePatternMatch;
import org.eclipse.incquery.runtime.exception.IncQueryException;
import org.eclipse.incquery.uml.derivedfeatures.util.NamedElementQualifiedNameQuerySpecification;
import org.eclipse.uml2.uml.NamedElement;

/**
 * Pattern-specific match representation of the org.eclipse.incquery.uml.derivedfeatures.namedElementQualifiedName pattern,
 * to be used in conjunction with {@link NamedElementQualifiedNameMatcher}.
 * 
 * <p>Class fields correspond to parameters of the pattern. Fields with value null are considered unassigned.
 * Each instance is a (possibly partial) substitution of pattern parameters,
 * usable to represent a match of the pattern in the result of a query,
 * or to specify the bound (fixed) input parameters when issuing a query.
 * 
 * @see NamedElementQualifiedNameMatcher
 * @see NamedElementQualifiedNameProcessor
 * 
 */
@SuppressWarnings("all")
public abstract class NamedElementQualifiedNameMatch extends BasePatternMatch {
  private NamedElement fNamedElement;
  
  private Object fQualifiedName;
  
  private static List<String> parameterNames = makeImmutableList("namedElement", "qualifiedName");
  
  private NamedElementQualifiedNameMatch(final NamedElement pNamedElement, final Object pQualifiedName) {
    this.fNamedElement = pNamedElement;
    this.fQualifiedName = pQualifiedName;
  }
  
  @Override
  public Object get(final String parameterName) {
    if ("namedElement".equals(parameterName)) return this.fNamedElement;
    if ("qualifiedName".equals(parameterName)) return this.fQualifiedName;
    return null;
  }
  
  public NamedElement getNamedElement() {
    return this.fNamedElement;
  }
  
  public Object getQualifiedName() {
    return this.fQualifiedName;
  }
  
  @Override
  public boolean set(final String parameterName, final Object newValue) {
    if (!isMutable()) throw new java.lang.UnsupportedOperationException();
    if ("namedElement".equals(parameterName) ) {
    	this.fNamedElement = (org.eclipse.uml2.uml.NamedElement) newValue;
    	return true;
    }
    if ("qualifiedName".equals(parameterName) && newValue instanceof java.lang.Object) {
    	this.fQualifiedName = (java.lang.Object) newValue;
    	return true;
    }
    return false;
  }
  
  public void setNamedElement(final NamedElement pNamedElement) {
    if (!isMutable()) throw new java.lang.UnsupportedOperationException();
    this.fNamedElement = pNamedElement;
  }
  
  public void setQualifiedName(final Object pQualifiedName) {
    if (!isMutable()) throw new java.lang.UnsupportedOperationException();
    this.fQualifiedName = pQualifiedName;
  }
  
  @Override
  public String patternName() {
    return "org.eclipse.incquery.uml.derivedfeatures.namedElementQualifiedName";
  }
  
  @Override
  public List<String> parameterNames() {
    return NamedElementQualifiedNameMatch.parameterNames;
  }
  
  @Override
  public Object[] toArray() {
    return new Object[]{fNamedElement, fQualifiedName};
  }
  
  @Override
  public NamedElementQualifiedNameMatch toImmutable() {
    return isMutable() ? newMatch(fNamedElement, fQualifiedName) : this;
  }
  
  @Override
  public String prettyPrint() {
    StringBuilder result = new StringBuilder();
    result.append("\"namedElement\"=" + prettyPrintValue(fNamedElement) + ", ");
    
    result.append("\"qualifiedName\"=" + prettyPrintValue(fQualifiedName)
    );
    return result.toString();
  }
  
  @Override
  public int hashCode() {
    final int prime = 31;
    int result = 1;
    result = prime * result + ((fNamedElement == null) ? 0 : fNamedElement.hashCode());
    result = prime * result + ((fQualifiedName == null) ? 0 : fQualifiedName.hashCode());
    return result;
  }
  
  @Override
  public boolean equals(final Object obj) {
    if (this == obj)
    	return true;
    if (!(obj instanceof NamedElementQualifiedNameMatch)) { // this should be infrequent
    	if (obj == null) {
    		return false;
    	}
    	if (!(obj instanceof IPatternMatch)) {
    		return false;
    	}
    	IPatternMatch otherSig  = (IPatternMatch) obj;
    	if (!specification().equals(otherSig.specification()))
    		return false;
    	return Arrays.deepEquals(toArray(), otherSig.toArray());
    }
    NamedElementQualifiedNameMatch other = (NamedElementQualifiedNameMatch) obj;
    if (fNamedElement == null) {if (other.fNamedElement != null) return false;}
    else if (!fNamedElement.equals(other.fNamedElement)) return false;
    if (fQualifiedName == null) {if (other.fQualifiedName != null) return false;}
    else if (!fQualifiedName.equals(other.fQualifiedName)) return false;
    return true;
  }
  
  @Override
  public NamedElementQualifiedNameQuerySpecification specification() {
    try {
    	return NamedElementQualifiedNameQuerySpecification.instance();
    } catch (IncQueryException ex) {
     	// This cannot happen, as the match object can only be instantiated if the query specification exists
     	throw new IllegalStateException (ex);
    }
  }
  
  /**
   * Returns an empty, mutable match.
   * Fields of the mutable match can be filled to create a partial match, usable as matcher input.
   * 
   * @return the empty match.
   * 
   */
  public static NamedElementQualifiedNameMatch newEmptyMatch() {
    return new Mutable(null, null);
  }
  
  /**
   * Returns a mutable (partial) match.
   * Fields of the mutable match can be filled to create a partial match, usable as matcher input.
   * 
   * @param pNamedElement the fixed value of pattern parameter namedElement, or null if not bound.
   * @param pQualifiedName the fixed value of pattern parameter qualifiedName, or null if not bound.
   * @return the new, mutable (partial) match object.
   * 
   */
  public static NamedElementQualifiedNameMatch newMutableMatch(final NamedElement pNamedElement, final Object pQualifiedName) {
    return new Mutable(pNamedElement, pQualifiedName);
  }
  
  /**
   * Returns a new (partial) match.
   * This can be used e.g. to call the matcher with a partial match.
   * <p>The returned match will be immutable. Use {@link #newEmptyMatch()} to obtain a mutable match object.
   * @param pNamedElement the fixed value of pattern parameter namedElement, or null if not bound.
   * @param pQualifiedName the fixed value of pattern parameter qualifiedName, or null if not bound.
   * @return the (partial) match object.
   * 
   */
  public static NamedElementQualifiedNameMatch newMatch(final NamedElement pNamedElement, final Object pQualifiedName) {
    return new Immutable(pNamedElement, pQualifiedName);
  }
  
  private static final class Mutable extends NamedElementQualifiedNameMatch {
    Mutable(final NamedElement pNamedElement, final Object pQualifiedName) {
      super(pNamedElement, pQualifiedName);
    }
    
    @Override
    public boolean isMutable() {
      return true;
    }
  }
  
  private static final class Immutable extends NamedElementQualifiedNameMatch {
    Immutable(final NamedElement pNamedElement, final Object pQualifiedName) {
      super(pNamedElement, pQualifiedName);
    }
    
    @Override
    public boolean isMutable() {
      return false;
    }
  }
}

==> org.eclipse.incquery.uml.source_1.2.0.201602080945.jar: org/eclipse/incquery/uml/derivedfeatures/NamedElementQualifiedNameMatch.java <==
package org.eclipse.incquery.uml.derivedfeatures;

import java.util.Arrays;
import java.util.List;
import org.eclipse.incquery.runtime.api.IPatternMatch;
import org.eclipse.incquery.runtime.api.impl.BasePatternMatch;
import org.eclipse.incquery.runtime.exception.IncQueryException;
import org.eclipse.incquery.uml.derivedfeatures.util.NamedElementQualifiedNameQuerySpecification;
import org.eclipse.uml2.uml.NamedElement;

/**
 * Pattern-specific match representation of the org.eclipse.incquery.uml.derivedfeatures.namedElementQualifiedName pattern,
 * to be used in conjunction with {@link NamedElementQualifiedNameMatcher}.
 * 
 * <p>Class fields correspond to parameters of the pattern. Fields with value null are considered unassigned.
 * Each instance is a (possibly partial) substitution of pattern parameters,
 * usable to represent a match of the pattern in the result of a query,
 * or to specify the bound (fixed) input parameters when issuing a query.
 * 
 * @see NamedElementQualifiedNameMatcher
 * @see NamedElementQualifiedNameProcessor
 * 
 */
@SuppressWarnings("all")
public abstract class NamedElementQualifiedNameMatch extends BasePatternMatch {
  private NamedElement fNamedElement;
  
  private Object fQualifiedName;
  
  private static List<String> parameterNames = makeImmutableList("namedElement", "qualifiedName");
  
  private NamedElementQualifiedNameMatch(final NamedElement pNamedElement, final Object pQualifiedName) {
    this.fNamedElement = pNamedElement;
    this.fQualifiedName = pQualifiedName;
  }
  
  @Override
  public Object get(final String parameterName) {
    if ("namedElement".equals(parameterName)) return this.fNamedElement;
    if ("qualifiedName".equals(parameterName)) return this.fQualifiedName;
    return null;
  }
  
  public NamedElement getNamedElement() {
    return this.fNamedElement;
  }
  
  public Object getQualifiedName() {
    return this.fQualifiedName;
  }
  
  @Override
  public boolean set(final String parameterName, final Object newValue) {
    if (!isMutable()) throw new java.lang.UnsupportedOperationException();
    if ("namedElement".equals(parameterName) ) {
    	this.fNamedElement = (NamedElement) newValue;
    	return true;
    }
    if ("qualifiedName".equals(parameterName) && newValue instanceof Object) {
    	this.fQualifiedName = (Object) newValue;
    	return true;
    }
    return false;
  }
  
  public void setNamedElement(final NamedElement pNamedElement) {
    if (!isMutable()) throw new java.lang.UnsupportedOperationException();
    this.fNamedElement = pNamedElement;
  }
  
  public void setQualifiedName(final Object pQualifiedName) {
    if (!isMutable()) throw new java.lang.UnsupportedOperationException();
    this.fQualifiedName = pQualifiedName;
  }
  
  @Override
  public String patternName() {
    return "org.eclipse.incquery.uml.derivedfeatures.namedElementQualifiedName";
  }
  
  @Override
  public List<String> parameterNames() {
    return NamedElementQualifiedNameMatch.parameterNames;
  }
  
  @Override
  public Object[] toArray() {
    return new Object[]{fNamedElement, fQualifiedName};
  }
  
  @Override
  public NamedElementQualifiedNameMatch toImmutable() {
    return isMutable() ? newMatch(fNamedElement, fQualifiedName) : this;
  }
  
  @Override
  public String prettyPrint() {
    StringBuilder result = new StringBuilder();
    result.append("\"namedElement\"=" + prettyPrintValue(fNamedElement) + ", ");
    
    result.append("\"qualifiedName\"=" + prettyPrintValue(fQualifiedName)
    );
    return result.toString();
  }
  
  @Override
  public int hashCode() {
    final int prime = 31;
    int result = 1;
    result = prime * result + ((fNamedElement == null) ? 0 : fNamedElement.hashCode());
    result = prime * result + ((fQualifiedName == null) ? 0 : fQualifiedName.hashCode());
    return result;
  }
  
  @Override
  public boolean equals(final Object obj) {
    if (this == obj)
    	return true;
    if (!(obj instanceof NamedElementQualifiedNameMatch)) { // this should be infrequent
    	if (obj == null) {
    		return false;
    	}
    	if (!(obj instanceof IPatternMatch)) {
    		return false;
    	}
    	IPatternMatch otherSig  = (IPatternMatch) obj;
    	if (!specification().equals(otherSig.specification()))
    		return false;
    	return Arrays.deepEquals(toArray(), otherSig.toArray());
    }
    NamedElementQualifiedNameMatch other = (NamedElementQualifiedNameMatch) obj;
    if (fNamedElement == null) {if (other.fNamedElement != null) return false;}
    else if (!fNamedElement.equals(other.fNamedElement)) return false;
    if (fQualifiedName == null) {if (other.fQualifiedName != null) return false;}
    else if (!fQualifiedName.equals(other.fQualifiedName)) return false;
    return true;
  }
  
  @Override
  public NamedElementQualifiedNameQuerySpecification specification() {
    try {
    	return NamedElementQualifiedNameQuerySpecification.instance();
    } catch (IncQueryException ex) {
     	// This cannot happen, as the match object can only be instantiated if the query specification exists
     	throw new IllegalStateException (ex);
    }
  }
  
  /**
   * Returns an empty, mutable match.
   * Fields of the mutable match can be filled to create a partial match, usable as matcher input.
   * 
   * @return the empty match.
   * 
   */
  public static NamedElementQualifiedNameMatch newEmptyMatch() {
    return new Mutable(null, null);
  }
  
  /**
   * Returns a mutable (partial) match.
   * Fields of the mutable match can be filled to create a partial match, usable as matcher input.
   * 
   * @param pNamedElement the fixed value of pattern parameter namedElement, or null if not bound.
   * @param pQualifiedName the fixed value of pattern parameter qualifiedName, or null if not bound.
   * @return the new, mutable (partial) match object.
   * 
   */
  public static NamedElementQualifiedNameMatch newMutableMatch(final NamedElement pNamedElement, final Object pQualifiedName) {
    return new Mutable(pNamedElement, pQualifiedName);
  }
  
  /**
   * Returns a new (partial) match.
   * This can be used e.g. to call the matcher with a partial match.
   * <p>The returned match will be immutable. Use {@link #newEmptyMatch()} to obtain a mutable match object.
   * @param pNamedElement the fixed value of pattern parameter namedElement, or null if not bound.
   * @param pQualifiedName the fixed value of pattern parameter qualifiedName, or null if not bound.
   * @return the (partial) match object.
   * 
   */
  public static NamedElementQualifiedNameMatch newMatch(final NamedElement pNamedElement, final Object pQualifiedName) {
    return new Immutable(pNamedElement, pQualifiedName);
  }
  
  private static final class Mutable extends NamedElementQualifiedNameMatch {
    Mutable(final NamedElement pNamedElement, final Object pQualifiedName) {
      super(pNamedElement, pQualifiedName);
    }
    
    @Override
    public boolean isMutable() {
      return true;
    }
  }
  
  private static final class Immutable extends NamedElementQualifiedNameMatch {
    Immutable(final NamedElement pNamedElement, final Object pQualifiedName) {
      super(pNamedElement, pQualifiedName);
    }
    
    @Override
    public boolean isMutable() {
      return false;
    }
  }
}
